==> ejc-jlincome-impl-3.0.0-20240605.033657-144-sources.jar: com/ejianc/business/jlincome/bid/controller/BusinessController.java <==
package com.ejianc.business.jlincome.bid.controller;

import java.io.Serializable;

import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import com.ejianc.business.jlincome.bid.bean.ResultRegisterEntity;
import com.ejianc.business.jlincome.bid.enums.BusinessStageEnum;
import com.ejianc.business.jlincome.bid.service.IResultRegisterService;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.foundation.support.vo.BillCodeParam;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.response.BillStateEnum;
import com.ejianc.framework.core.util.ExcelExport;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.*;
import java.util.stream.Collectors;
import com.alibaba.fastjson.JSONObject;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;
import org.apache.commons.collections.CollectionUtils;
import javax.servlet.http.HttpServletResponse;

import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.beans.factory.annotation.Autowired;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.kit.collection.ListUtil;
import com.ejianc.framework.auth.session.SessionManager;
import com.ejianc.framework.auth.session.UserContext;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;

import com.ejianc.business.jlincome.bid.bean.BusinessEntity;
import com.ejianc.business.jlincome.bid.service.IBusinessService;
import com.ejianc.business.jlincome.bid.vo.BusinessVO;

/**
 * 投标-商机登记
 *
 * @author generator
 *
 */
@Controller
@RequestMapping("business")
public class BusinessController implements Serializable {
	private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IBillTypeApi billTypeApi;
    @Autowired
    private IBillCodeApi billCodeApi;
    @Autowired
    private IOrgApi iOrgApi;

    private static final String BILL_CODE = "BUSINESS";//此处需要根据实际修改

    @Autowired
    private IBusinessService service;

    @Autowired
    private SessionManager sessionManager;

    /**
     * @Description saveOrUpdate 新增或者修改
     */
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<BusinessVO> saveOrUpdate(@RequestBody BusinessVO saveOrUpdateVO) {
    	BusinessEntity entity = BeanMapper.map(saveOrUpdateVO, BusinessEntity.class);
    	if(entity.getId() == null || entity.getId() == 0){
    	    entity.setAbandonFlag(false);
            BillCodeParam billCodeParam = BillCodeParam.build(BILL_CODE,InvocationInfoProxy.getTenantid(),saveOrUpdateVO);
            CommonResponse<String> billCode = billCodeApi.generateBillCode(billCodeParam);
            if(billCode.isSuccess()) {
                entity.setBillCode(billCode.getData());//此处需要根据实际修改 删除本行或者上一行
            }else{
                throw new BusinessException("网络异常， 编码生成失败， 请稍后再试");
            }
        }
    	service.saveOrUpdate(entity, false);
    	BusinessVO vo = BeanMapper.map(entity, BusinessVO.class);
    	return CommonResponse.success("保存或修改单据成功！",vo);
    }

    /**
     * @Description queryDetail 查询详情
     * @param id
     */
    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<BusinessVO> queryDetail(Long id) {
    	BusinessEntity entity = service.selectById(id);
    	BusinessVO vo = BeanMapper.map(entity, BusinessVO.class);
        return CommonResponse.success("查询详情数据成功！",vo);
    }

    /**
     * @Description delete 批量删除单据
     * @Param [ids]
     */
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> delete(@RequestBody List<BusinessVO> vos) {
        if(ListUtil.isNotEmpty(vos)){
            for (BusinessVO vo : vos) {
                // 参数是单据类型编码字符串 根据需求是否打开下面代码
                /* CommonResponse<String> resp = billTypeApi.checkQuote("billTypeCode", vo.getId());
                if(!resp.isSuccess()){
                    return CommonResponse.error("删除失败！"+resp.getMsg());
                }*/
            }
        }
        service.removeByIds(vos.stream().map(BusinessVO::getId).collect(Collectors.toList()),true);
        return CommonResponse.success("删除成功！");
    }

    /**
     * @Description queryList 查询列表
     * @param param
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<BusinessVO>> queryList(@RequestBody QueryParam param) {

        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.add("billCode");
        fuzzyFields.add("projectName");
        fuzzyFields.add("orgName");
        fuzzyFields.add("projectTypeName");
        fuzzyFields.add("productTypeName");
        fuzzyFields.add("customName");
        fuzzyFields.add("infoSourceName");
        fuzzyFields.add("saleLeaderName");
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));

        if(null != param.getParams().get("selfFlag")){
            String selfFlag = param.getParams().get("selfFlag").getValue().toString();
            param.getParams().remove("selfFlag");
            if ("1".equals(selfFlag)){
                param.getParams().put("saleLeaderId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getEmployeeId()));
            }
        }

        /** 数据隔离 本下 没有组织orgId的删除下面代码-------------开始 */
        param.getParams().put("orgId",new Parameter(QueryParam.IN,iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        /** 数据隔离 本下 没有组织orgId的删除上面代码-------------结束！！！ */

        IPage<BusinessEntity> page = service.queryPage(param,false);
        IPage<BusinessVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
  		pageData.setRecords(BeanMapper.mapList(page.getRecords(), BusinessVO.class));

        return CommonResponse.success("查询列表数据成功！",pageData);
    }

    /**
     * 获取RPC数据
     * resp 返回值
     * isMustSuc 是否必须成功
     * errMsg 失败提示
     */
    private Object getRespData(CommonResponse<?> resp, boolean isMustSuc, String errMsg) {
        if(isMustSuc && !resp.isSuccess()) {
            throw new BusinessException(StringUtils.isNoneBlank(errMsg) ? errMsg : "调用Rpc服务失败");
        }
        return resp.getData();
    }


    /**
     * @Description 导出
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/excelExport", method = RequestMethod.POST)
    @ResponseBody
    public void excelExport(@RequestBody QueryParam param, HttpServletResponse response) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.add("billCode");
        fuzzyFields.add("projectName");
        fuzzyFields.add("orgName");
        fuzzyFields.add("projectTypeName");
        fuzzyFields.add("productTypeName");
        fuzzyFields.add("customName");
        fuzzyFields.add("infoSourceName");
        fuzzyFields.add("saleLeaderName");
        param.getParams().put("tenant_id",new Parameter(QueryParam.EQ,InvocationInfoProxy.getTenantid()));
        param.setPageIndex(1);
        param.setPageSize(-1);
        /** 数据隔离 本下 没有组织orgId的删除下面代码-------------开始 */
        param.getParams().put("orgId",new Parameter(QueryParam.IN,iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        /** 数据隔离 本下 没有组织orgId的删除上面代码-------------结束！！！ */


        List<BusinessEntity> list = service.queryList(param);
        //todo:字段翻译等等
        Map<String, Object> beans = new HashMap<>();
        List<BusinessVO> voList = BeanMapper.mapList(list, BusinessVO.class);
        voList.forEach(e -> {
            e.setBillStateName(BillStateEnum.getEnumByStateCode(e.getBillState()).getDescription());
            e.setAbandonFlagName(null != e.getAbandonFlag() ? "是" : "否");
            e.setBusinessStageName("0".equals(e.getBusinessStage()) ? "跟踪" : "1".equals(e.getBusinessStage()) ? "中标" : "放弃");
        });
        beans.put("records", voList);
        ExcelExport.getInstance().export("Business-export.xlsx", beans, response);
    }

    /**
     * @Description 参照
     * @Return void
     */
    @RequestMapping(value = "/refBusinessData", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<IPage<BusinessVO>> refBusinessData(@RequestParam Integer pageNumber, @RequestParam Integer pageSize,
                                                                        String condition,
                                                                        String searchObject,
                                                                        String searchText) {
        QueryParam param = new QueryParam();
        param.setPageSize(pageSize);
        param.setPageIndex(pageNumber);
        param.setSearchText(searchText);
        param.setSearchObject(searchObject);
        //设置模糊查询
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.add("billCode");
        fuzzyFields.add("projectName");
        fuzzyFields.add("orgName");
        fuzzyFields.add("projectTypeName");
        fuzzyFields.add("productTypeName");
        fuzzyFields.add("saleLeaderName");
        fuzzyFields.add("saleLeaderPhone");

        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        if (StringUtils.isNotEmpty(condition)) {
            /** 处理condition */
            JSONObject _con = JSONObject.parseObject(condition);
        }
        /**
         * 数据过滤
         */
        param.getParams().put("billState", new Parameter(QueryParam.IN, Arrays.asList(
                BillStateEnum.COMMITED_STATE.getBillStateCode(),
                BillStateEnum.PASSED_STATE.getBillStateCode()
        )));
        param.getOrderMap().put("createTime", QueryParam.DESC);
        IPage<BusinessEntity> page = service.queryPage(param, false);
        IPage<BusinessVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());

        List<BusinessVO> list = BeanMapper.mapList(page.getRecords(), BusinessVO.class);
        pageData.setRecords(list);

        return CommonResponse.success("查询参照数据成功！", pageData);
     }


    /**
     * @Description updateAbandonFlag 修改放弃状态
     * @param id
     */
    @RequestMapping(value = "/updateAbandonFlag", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<String> updateAbandonFlag(Long id, Boolean abandonFlag) {
        return service.updateAbandonFlag(id, abandonFlag);
    }

}

==> ejc-jlincome-impl-3.0.0-20240713.013625-169-sources.jar: com/ejianc/business/jlincome/bid/controller/BusinessController.java <==
package com.ejianc.business.jlincome.bid.controller;

import java.io.Serializable;

import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import com.ejianc.business.jlincome.bid.bean.ResultRegisterEntity;
import com.ejianc.business.jlincome.bid.enums.BusinessStageEnum;
import com.ejianc.business.jlincome.bid.service.IResultRegisterService;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.foundation.share.api.IProjectArchiveApi;
import com.ejianc.foundation.support.vo.BillCodeParam;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.response.BillStateEnum;
import com.ejianc.framework.core.util.ExcelExport;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.*;
import java.util.stream.Collectors;
import com.alibaba.fastjson.JSONObject;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;
import org.apache.commons.collections.CollectionUtils;
import javax.servlet.http.HttpServletResponse;

import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.beans.factory.annotation.Autowired;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.kit.collection.ListUtil;
import com.ejianc.framework.auth.session.SessionManager;
import com.ejianc.framework.auth.session.UserContext;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;

import com.ejianc.business.jlincome.bid.bean.BusinessEntity;
import com.ejianc.business.jlincome.bid.service.IBusinessService;
import com.ejianc.business.jlincome.bid.vo.BusinessVO;

/**
 * 投标-商机登记
 *
 * @author generator
 *
 */
@Controller
@RequestMapping("business")
public class BusinessController implements Serializable {
	private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IBillTypeApi billTypeApi;
    @Autowired
    private IBillCodeApi billCodeApi;
    @Autowired
    private IOrgApi iOrgApi;

    private static final String BILL_CODE = "BUSINESS";//此处需要根据实际修改

    @Autowired
    private IBusinessService service;

    @Autowired
    private SessionManager sessionManager;

    @Autowired
    private IProjectArchiveApi projectArchiveApi;


    /**
     * @Description saveOrUpdate 新增或者修改
     */
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<BusinessVO> saveOrUpdate(@RequestBody BusinessVO saveOrUpdateVO) {
    	BusinessEntity entity = BeanMapper.map(saveOrUpdateVO, BusinessEntity.class);
    	if(entity.getId() == null || entity.getId() == 0){
    	    entity.setAbandonFlag(false);
            BillCodeParam billCodeParam = BillCodeParam.build(BILL_CODE,InvocationInfoProxy.getTenantid(),saveOrUpdateVO);
            CommonResponse<String> billCode = billCodeApi.generateBillCode(billCodeParam);
            if(billCode.isSuccess()) {
                entity.setBillCode(billCode.getData());//此处需要根据实际修改 删除本行或者上一行
            }else{
                throw new BusinessException("网络异常， 编码生成失败， 请稍后再试");
            }
        }
    	if (null != entity.getBillState() && (1 == entity.getBillState() || 3 == entity.getBillState())){
            BusinessEntity oldEntity = service.selectById(saveOrUpdateVO.getId());
            if ((null == oldEntity.getBusinessRound() && null != saveOrUpdateVO.getBusinessRound()) || (null != oldEntity.getBusinessRound() && null != saveOrUpdateVO.getBusinessRound() && oldEntity.getBusinessRound() != saveOrUpdateVO.getBusinessRound())){
                CommonResponse<String> projectArchiveRes = projectArchiveApi.updateBusinessRound(entity.getBusinessRound(), entity.getId());
                if (!projectArchiveRes.isSuccess()){
                    throw new BusinessException("修改项目信息-商机阶段失败，原因-" + projectArchiveRes.getMsg());
                }
            }
        }
    	service.saveOrUpdate(entity, false);
    	BusinessVO vo = BeanMapper.map(entity, BusinessVO.class);
    	return CommonResponse.success("保存或修改单据成功！",vo);
    }

    /**
     * @Description queryDetail 查询详情
     * @param id
     */
    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<BusinessVO> queryDetail(Long id) {
    	BusinessEntity entity = service.selectById(id);
    	BusinessVO vo = BeanMapper.map(entity, BusinessVO.class);
        return CommonResponse.success("查询详情数据成功！",vo);
    }

    /**
     * @Description delete 批量删除单据
     * @Param [ids]
     */
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> delete(@RequestBody List<BusinessVO> vos) {
        if(ListUtil.isNotEmpty(vos)){
            for (BusinessVO vo : vos) {
                // 参数是单据类型编码字符串 根据需求是否打开下面代码
                /* CommonResponse<String> resp = billTypeApi.checkQuote("billTypeCode", vo.getId());
                if(!resp.isSuccess()){
                    return CommonResponse.error("删除失败！"+resp.getMsg());
                }*/
            }
        }
        service.removeByIds(vos.stream().map(BusinessVO::getId).collect(Collectors.toList()),true);
        return CommonResponse.success("删除成功！");
    }

    /**
     * @Description queryList 查询列表
     * @param param
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<BusinessVO>> queryList(@RequestBody QueryParam param) {

        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.add("billCode");
        fuzzyFields.add("projectName");
        fuzzyFields.add("orgName");
        fuzzyFields.add("projectTypeName");
        fuzzyFields.add("productTypeName");
        fuzzyFields.add("customName");
        fuzzyFields.add("infoSourceName");
        fuzzyFields.add("saleLeaderName");
        fuzzyFields.add("businessRound");
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));

        if(null != param.getParams().get("selfFlag")){
            String selfFlag = param.getParams().get("selfFlag").getValue().toString();
            param.getParams().remove("selfFlag");
            if ("1".equals(selfFlag)){
                param.getParams().put("saleLeaderId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getEmployeeId()));
            }
        }

        /** 数据隔离 本下 没有组织orgId的删除下面代码-------------开始 */
        param.getParams().put("orgId",new Parameter(QueryParam.IN,iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        /** 数据隔离 本下 没有组织orgId的删除上面代码-------------结束！！！ */

        IPage<BusinessEntity> page = service.queryPage(param,false);
        IPage<BusinessVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
  		pageData.setRecords(BeanMapper.mapList(page.getRecords(), BusinessVO.class));

        return CommonResponse.success("查询列表数据成功！",pageData);
    }

    /**
     * 获取RPC数据
     * resp 返回值
     * isMustSuc 是否必须成功
     * errMsg 失败提示
     */
    private Object getRespData(CommonResponse<?> resp, boolean isMustSuc, String errMsg) {
        if(isMustSuc && !resp.isSuccess()) {
            throw new BusinessException(StringUtils.isNoneBlank(errMsg) ? errMsg : "调用Rpc服务失败");
        }
        return resp.getData();
    }


    /**
     * @Description 导出
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/excelExport", method = RequestMethod.POST)
    @ResponseBody
    public void excelExport(@RequestBody QueryParam param, HttpServletResponse response) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.add("billCode");
        fuzzyFields.add("projectName");
        fuzzyFields.add("orgName");
        fuzzyFields.add("projectTypeName");
        fuzzyFields.add("productTypeName");
        fuzzyFields.add("customName");
        fuzzyFields.add("infoSourceName");
        fuzzyFields.add("saleLeaderName");
        fuzzyFields.add("businessRound");
        param.getParams().put("tenant_id",new Parameter(QueryParam.EQ,InvocationInfoProxy.getTenantid()));
        param.setPageIndex(1);
        param.setPageSize(-1);
        /** 数据隔离 本下 没有组织orgId的删除下面代码-------------开始 */
        param.getParams().put("orgId",new Parameter(QueryParam.IN,iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        /** 数据隔离 本下 没有组织orgId的删除上面代码-------------结束！！！ */


        List<BusinessEntity> list = service.queryList(param);
        //todo:字段翻译等等
        Map<String, Object> beans = new HashMap<>();
        List<BusinessVO> voList = BeanMapper.mapList(list, BusinessVO.class);
        voList.forEach(e -> {
            e.setBillStateName(BillStateEnum.getEnumByStateCode(e.getBillState()).getDescription());
            e.setAbandonFlagName(null != e.getAbandonFlag() ? "是" : "否");
            e.setBusinessStageName("0".equals(e.getBusinessStage()) ? "跟踪" : "1".equals(e.getBusinessStage()) ? "中标" : "放弃");
            if (null != e.getBusinessRound()){
                switch (e.getBusinessRound()) {
                    case 0:
                        e.setBusinessRoundName("项目立项");
                        break;
                    case 1:
                        e.setBusinessRoundName("设计方案");
                        break;
                    case 2:
                        e.setBusinessRoundName("业主招标");
                        break;
                    case 3:
                        e.setBusinessRoundName("总包招标");
                        break;
                    case 4:
                        e.setBusinessRoundName("合同签订");
                        break;
                }
            }
        });
        beans.put("records", voList);
        ExcelExport.getInstance().export("Business-export.xlsx", beans, response);
    }

    /**
     * @Description 参照
     * @Return void
     */
    @RequestMapping(value = "/refBusinessData", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<IPage<BusinessVO>> refBusinessData(@RequestParam Integer pageNumber, @RequestParam Integer pageSize,
                                                                        String condition,
                                                                        String searchObject,
                                                                        String searchText) {
        QueryParam param = new QueryParam();
        param.setPageSize(pageSize);
        param.setPageIndex(pageNumber);
        param.setSearchText(searchText);
        param.setSearchObject(searchObject);
        //设置模糊查询
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.add("billCode");
        fuzzyFields.add("projectName");
        fuzzyFields.add("orgName");
        fuzzyFields.add("projectTypeName");
        fuzzyFields.add("productTypeName");
        fuzzyFields.add("saleLeaderName");
        fuzzyFields.add("saleLeaderPhone");

        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        if (StringUtils.isNotEmpty(condition)) {
            /** 处理condition */
            JSONObject _con = JSONObject.parseObject(condition);
        }
        /**
         * 数据过滤
         */
        param.getParams().put("billState", new Parameter(QueryParam.IN, Arrays.asList(
                BillStateEnum.COMMITED_STATE.getBillStateCode(),
                BillStateEnum.PASSED_STATE.getBillStateCode()
        )));
        param.getOrderMap().put("createTime", QueryParam.DESC);
        IPage<BusinessEntity> page = service.queryPage(param, false);
        IPage<BusinessVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());

        List<BusinessVO> list = BeanMapper.mapList(page.getRecords(), BusinessVO.class);
        pageData.setRecords(list);

        return CommonResponse.success("查询参照数据成功！", pageData);
     }


    /**
     * @Description updateAbandonFlag 修改放弃状态
     * @param id
     */
    @RequestMapping(value = "/updateAbandonFlag", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<String> updateAbandonFlag(Long id, Boolean abandonFlag) {
        return service.updateAbandonFlag(id, abandonFlag);
    }

    /**
     * @Description updateBusinessRound 修改商机阶段
     * @param id
     */
    @RequestMapping(value = "/updateBusinessRound", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<String> updateBusinessRound(Long id, Integer businessRound) {
        return service.updateBusinessRound(id, businessRound);
    }

}
